translate.storage.tbx.tbxunit

Package translate :: Package storage :: Module tbx :: Class tbxunit |
[hide private]
[frames] | no frames]

# Class tbxunit

source code

A single term in the TBX file. Provisional work is done to make several languages possible.

Instance Methods | [hide private]
createlanguageNode(self, lang, text, purpose) returns a langset xml Element setup with given parameters | source code
string |
getid(self) A unique identifier for this unit. | source code
Inherited from `lisa.LISAunit`: `__eq__`, `__init__`, `__str__`, `createPHnodes`, `getNodeText`, `getlanguageNode`, `getlanguageNodes`, `namespaced` Inherited from `lisa.LISAunit` (private): `_set_property` Inherited from `base.TranslationUnit`: `get_state_id`, `get_state_n`, `getcontext`, `getunits`, `hasplural`, `infer_state`, `isblank`, `isfuzzy`, `isheader`, `isobsolete`, `isreview`, `istranslatable`, `istranslated`, `makeobsolete`, `markfuzzy`, `markreviewneeded`, `merge`, `multistring_to_rich`, `set_state_n`, `setcontext`, `setid`, `unit_iter` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`
Source
Inherited from `lisa.LISAunit`: `get_source_dom`, `getsource`, `set_source_dom`, `setsource` Inherited from `base.TranslationUnit`: `getsourcelanguage` Inherited from `base.TranslationUnit` (private): `_get_rich_source`, `_set_rich_source`
Target
Inherited from `lisa.LISAunit`: `get_target_dom`, `gettarget`, `set_target_dom`, `settarget`, `target_dom` Inherited from `base.TranslationUnit`: `gettargetlanguage`, `gettargetlen` Inherited from `base.TranslationUnit` (private): `_get_rich_target`, `_set_rich_target`
Notes
Inherited from `base.TranslationUnit`: `addnote`, `getnotes`, `removenotes`
Locations
Inherited from `base.TranslationUnit`: `addlocation`, `addlocations`, `getlocations`
Errors
Inherited from `base.TranslationUnit`: `adderror`, `geterrors`

Class Methods | [hide private]
Inherited from `lisa.LISAunit`: `createfromxmlElement` Inherited from `base.TranslationUnit`: `buildfromunit`, `rich_to_multistring`

Class Variables | [hide private]
| rootNode = `"termEntry"`
| languageNode = `"langSet"`
| textNode = `"term"`
Inherited from `lisa.LISAunit`: `namespace`, `rid`, `xid` Inherited from `lisa.LISAunit` (private): `_default_xml_space` Inherited from `base.TranslationUnit`: `STATE`, `S_EMPTY`, `S_FINAL`, `S_NEEDS_REVIEW`, `S_NEEDS_WORK`, `S_OBSOLETE`, `S_REJECTED`, `S_UNREVIEWED`, `rich_parsers` Inherited from `base.TranslationUnit` (private): `_state_n`, `_store`
Source
Inherited from `lisa.LISAunit`: `source`, `source_dom` Inherited from `base.TranslationUnit` (private): `_rich_source`, `_source`
Target
Inherited from `lisa.LISAunit`: `target` Inherited from `base.TranslationUnit` (private): `_rich_target`, `_target`
Notes
Inherited from `base.TranslationUnit`: `notes`

Properties | [hide private]
Inherited from `object`: `__class__`
Source
Inherited from `base.TranslationUnit`: `rich_source`
Target
Inherited from `base.TranslationUnit`: `rich_target`

Method Details | [hide private]

### createlanguageNode(self, lang, text, purpose) | source code
returns a langset xml Element setup with given parameters Overrides: lisa.LISAunit.createlanguageNode

### getid(self) | source code
A unique identifier for this unit. Returns: string an identifier for this unit that is unique in the store Derived classes should override this in a way that guarantees a unique identifier for each unit in the store. Overrides: base.TranslationUnit.getid (inherited documentation)